@@ -27,40 +27,37 @@ from __future__ import unicode_literals
 lilypond_keywords = (
     'accepts',
     'alias',
-    'consists',
-    'defaultchild',
-    'denies',
-    #'description',
-    #'grobdescriptions',
-    'hide', # since 2.18
-    'include',
-    #'invalid',
-    'language',
-    'name',
-    #'objectid',
-    'omit', # since 2.18
-    'once',
-    'set',
-    'unset',
-    'override',
-    'revert',
-    'remove',
-    'temporary', # since 2.18
-    #'sequential',
-    #'simultaneous',
-    #'type',
-    'undo', # since 2.18 (not mentioned in the command index)
-    'version',
-    'score',
     'book',
     'bookpart',
-    'header',
-    'paper',
-    'midi',
-    'layout',
-    'with',
+    'consists',
     'context',
+    'defaultchild',
+    'denies',
+    'description',
+    'etc',
+    'header',
+    'hide', # since 2.18
+    'include',
+    'inherit-acceptability',
+    'language',
+    'layout',
+    'midi',
+    'name',
+    'omit', # since 2.18
+    'once',
+    'override',
+    'paper',
+    'remove',
+    'revert',
+    'score',
+    'set',
     'tagGroup', # since 2.20
+    'temporary', # since 2.18
+    'type',
+    'undo', # since 2.18 (not mentioned in the command index)
+    'unset',
+    'version',
+    'with',
 )
 
 
@@ -72,13 +69,19 @@ lilypond_music_commands = (
     'addInstrumentDefinition',
     'addlyrics',
     'addQuote',
+    'after',
     'afterGrace',
     #'afterGraceFraction', # this is a parser variable
     'aikenHeads',
     'aikenHeadsMinor',
+    'aikenThinHeads',
+    'aikenThinHeadsMinor',
+    'allowBreak',
     'allowPageTurn',
+    'allowVoltaHook',
     'alterBroken', # since 2.18 (?)
     'alternative',
+    'ambitusAfter',
     #'AncientRemoveEmptyStaffContext',
     'appendToTag', # since 2.16
     'applyContext',
@@ -92,13 +95,23 @@ lilypond_music_commands = (
     'arpeggioBracket',
     'arpeggioNormal',
     'arpeggioParenthesis',
+    'arpeggioParenthesisDashed',
     'ascendens',
+    'assertBeamQuant',
+    'assertBeamSlope',
     'auctum',
+    'aug',
     'augmentum',
     'autoAccidentals',
     'autoBeamOff',
     'autoBeamOn',
-    'autochange',
+    'autoBreaksOff',
+    'autoBreaksOn',
+    'autoChange',
+    'autoLineBreaksOff',
+    'autoLineBreaksOn',
+    'autoPageBreaksOff',
+    'autoPageBreaksOn',
     'balloonGrobText',
     'balloonLengthOff',
     'balloonLengthOn',
@@ -112,6 +125,8 @@ lilypond_music_commands = (
     'bassFigureStaffAlignmentUp',
     'beamExceptions', # since 2.20
     'bendAfter',
+    'bendHold', # since 2.23
+    'bendStartLevel',
     'blackTriangleMarkup',
     'bookOutputName',
     'bookOutputSuffix',
@@ -128,13 +143,15 @@ lilypond_music_commands = (
     'chordmode',
     #'chordNameSeparator',
     #'chordPrefixSpacer',
-    #'chordRootNamer',
     'chordRepeats', # since 2.16
+    #'chordRootNamer',
     'chords',
     'clef',
     'cm',
     'compoundMeter', # since 2.16
-    'compressFullBarRests',
+    #'compressFullBarRests', renamed to compressEmptyMeasures
+    'compressEmptyMeasures',
+    'compressMMRests', # since 2.23
     'context',
     'cr',
     'cresc',
@@ -153,6 +170,8 @@ lilypond_music_commands = (
     'dashPlus',
     'dashUnderscore',
     'deadNote',  # since 2.16
+    'deadNotesOff',
+    'deadNotesOn',
     'decr',
     'default',
     'defaultNoteHeads',  # since 2.16
@@ -160,6 +179,10 @@ lilypond_music_commands = (
     'defineBarLine', # since 2.18
     'deminutum',
     'denies',
+    'deprecatedcresc',
+    'deprecateddim',
+    'deprecatedendcresc',
+    'deprecatedenddim',
     'descendens',
     'dim',
     'dimHairpin',
@@ -168,12 +191,14 @@ lilypond_music_commands = (
     'dimTextDim',
     'displayLilyMusic',
     'displayMusic',
+    'displayScheme', # since 2.23
     'divisioMaior',
     'divisioMaxima',
     'divisioMinima',
     'dotsDown',
     'dotsNeutral',
     'dotsUp',
+    'dropNote', # since 2.23
     'drummode',
     'drumPitchTable',
     'drums',
@@ -182,11 +207,13 @@ lilypond_music_commands = (
     'dynamicUp',
     'easyHeadsOff',
     'easyHeadsOn',
+    'enablePolymeter',
     'endcr',
     'endcresc',
     'enddecr',
     'enddim',
     'endincipit',
+    'endSkipNCs',
     'endSpanners',
     'episemFinis',
     'episemInitium',
@@ -195,6 +222,8 @@ lilypond_music_commands = (
     'escapedParenthesisCloseSymbol',
     'escapedParenthesisOpenSymbol',
     'escapedSmallerSymbol',
+    'eventChords', # since 2.23
+    'expandEmptyMeasures',
     'expandFullBarRests',
     'f',
     'featherDurations',
@@ -206,8 +235,12 @@ lilypond_music_commands = (
     'figuremode',
     'figures',
     'finalis',
+    'fine',
+    'finger', # since 2.23
     'fingeringOrientations',
+    'fixed', # since 2.23
     'flexa',
+    'footnote', # since 2.23
     'fp',
     'frenchChords',
     'fullJazzExceptions',
@@ -218,8 +251,15 @@ lilypond_music_commands = (
     'glissando',
     'grace',
     'graceSettings',
+    'grobdescriptions', # since 2.23
     'harmonic',
+    'harmonicByFret', # since 2.20
+    'harmonicByRatio', # since 2.20
+    'harmonicNote',
+    'harmonicsOff',
+    'harmonicsOn',
     'hideNotes',
+    'hideSplitTiedTabNotes',
     'hideStaffSwitch',
     'huge',
     'ignatzekExceptionMusic',
@@ -231,18 +271,27 @@ lilypond_music_commands = (
     'improvisationOff',
     'improvisationOn',
     'in',
+    'incipit',
     'inclinatum',
     'includePageLayoutFile',
     'indent',
+    'inStaffSegno', # since 2.23
     'instrumentSwitch',
     'instrumentTransposition',
     'interscoreline',
+    'inversion', # since 2.23
+    'invertChords', # since 2.23
     'italianChords',
+    'jump',
     'keepWithTag',
     'key',
+    'kievanOff',
+    'kievanOn',
     'killCues',
     'label',
     'laissezVibrer',
+    'languageRestore', # since 2.23
+    'languageSaveAndChange', # since 2.23
     'large',
     'ligature',
     'linea',
@@ -251,16 +300,21 @@ lilypond_music_commands = (
     'lyrics',
     'lyricsto',
     'magnifyMusic', # since 2.20
+    'magnifyStaff', # since 2.23
     'maininput',
+    'maj',
     'majorSevenSymbol',
     'makeClusters',
+    'makeDefaultStringTuning',
     'mark',
     'markLengthOff', # since 2.18
     'markLengthOn',  # since 2.18
     'markup',
     'markuplines', # deprecated, till 2.14
     'markuplist', # from 2.16
+    'markupMap', #since 2.23
     'maxima',
+    'medianChordGridStyle',
     'melisma',
     'melismaEnd',
     'mergeDifferentlyDottedOff',
@@ -269,6 +323,8 @@ lilypond_music_commands = (
     'mergeDifferentlyHeadedOn',
     'mf',
     'mm',
+    'modalInversion', # since 2.23
+    'modalTranspose', # since 2.23
     'mp',
     'musicMap',
     'neumeDemoLayout',
@@ -282,6 +338,7 @@ lilypond_music_commands = (
     'notemode',
     'numericTimeSignature',
     'octaveCheck',
+    'offset', # since 2.23
     'oldaddlyrics',
     'oneVoice',
     'oriscus',
@@ -293,20 +350,33 @@ lilypond_music_commands = (
     'pageBreak',
     'pageTurn',
     'palmMute',  # since 2.16
+    'palmMuteOff',
     'palmMuteOn',  # since 2.16
     'parallelMusic',
     'parenthesisCloseSymbol',
     'parenthesisOpenSymbol',
     'parenthesize',
-    'partcombine',
+    'partCombine',
+    'partCombineApart',
+    'partCombineAutomatic',
+    'partCombineChords',
+    'partCombineDown', # since 2.23
+    'partCombineForce',
     'partCombineListener',
+    'partCombineSoloI',
+    'partCombineSoloII',
+    'partCombineUnisono',
+    'partCombineUp', # since 2.23
     'partial',
     'partialJazzExceptions',
     'partialJazzMusic',
     'pes',
     'phrasingSlurDashed',
+    'phrasingSlurDashPattern',
     'phrasingSlurDotted',
     'phrasingSlurDown',
+    'phrasingSlurHalfDashed',
+    'phrasingSlurHalfSolid',
     'phrasingSlurNeutral',
     'phrasingSlurSolid',
     'phrasingSlurUp',
@@ -314,16 +384,26 @@ lilypond_music_commands = (
     'pitchedTrill',
     'pointAndClickOff',
     'pointAndClickOn',
+    'pointAndClickTypes',
     'pp',
     'ppp',
     'pppp',
     'ppppp',
+    'preBend', # since 2.23
+    'preBendHold', # since 2.23
     'predefinedFretboardsOff',
     'predefinedFretboardsOn',
+    'propertyOverride', # since 2.23
+    'propertyRevert', # since 2.23
+    'propertySet', # since 2.23
+    'propertyTweak', # since 2.23
+    'propertyUnset', # since 2.23
     'pt',
     'pushToTag', # since 2.16
     'quilisma',
     'quoteDuring',
+    'raiseNote', # since 2.23
+    'reduceChords', # since 2.23
     'relative',
     'RemoveEmptyRhythmicStaffContext',
     'RemoveEmptyStaffContext',
@@ -333,7 +413,9 @@ lilypond_music_commands = (
     'resetRelativeOctave',
     'responsum',
     'rest',
+    'retrograde', # since 2.23
     'revert',
+    'revertTimeSignatureSettings', # since 2.23
     'rfz',
     'rightHandFinger',
     'romanStringNumbers', # since 2.20
@@ -341,8 +423,13 @@ lilypond_music_commands = (
     'sacredHarpHeadsMinor',
     'scaleDurations',
     'scoreTweak',
+    'section',
+    'sectionLabel',
+    'segnoMark',
     'semiGermanChords',
     'set',
+    'setDefaultDurationToQuarter',
+    'settingsFrom', # 2.23
     'sf',
     'sff',
     'sfp',
@@ -353,13 +440,20 @@ lilypond_music_commands = (
     'shiftOn',
     'shiftOnn',
     'shiftOnnn',
+    'showSplitTiedTabNotes',
     'showStaffSwitch',
     'single', # since 2.18
     'skip',
+    'skipNC',
+    'skipNCs',
     'skipTypesetting',
+    'slashedGrace', # since 2.20
     'slurDashed',
+    'slurDashPattern',
     'slurDotted',
     'slurDown',
+    'slurHalfDashed',
+    'slurHalfSolid',
     'slurNeutral',
     'slurSolid',
     'slurUp',
@@ -371,10 +465,15 @@ lilypond_music_commands = (
     'sp',
     'spacingTweaks',
     'spp',
+    'staff-space',
+    'staffHighlight',
     'startAcciaccaturaMusic',
     'startAppoggiaturaMusic',
     'startGraceMusic',
     'startGroup',
+    'startMeasureCount',
+    'startMeasureSpanner',
+    'startSlashedGraceMusic',
     'startStaff',
     'startTextSpan',
     'startTrillSpan',
@@ -385,27 +484,40 @@ lilypond_music_commands = (
     'stopAppoggiaturaMusic',
     'stopGraceMusic',
     'stopGroup',
+    'stopMeasureCount',
+    'stopMeasureSpanner',
+    'stopSlashedGraceMusic',
     'stopStaff',
+    'stopStaffHighlight',
     'stopTextSpan',
     'stopTrillSpan',
+    'storePredefinedDiagram',
     'stringTuning', # since 2.16
     'strokeFingerOrientations',
     'stropha',
+    'styledNoteHeads', # since 2.23
     'sustainOff',
     'sustainOn',
+    'tabChordRepeats',
+    'tabChordRepetition',
     'tabFullNotation',
     'tag',
     'teeny',
     'tempo',
     'tempoWholesPerMinute',
+    'textEndMark',
     'textLengthOff',
     'textLengthOn',
+    'textMark',
     'textSpannerDown',
     'textSpannerNeutral',
     'textSpannerUp',
     'tieDashed',
+    'tieDashPattern',
     'tieDotted',
     'tieDown',
+    'tieHalfDashed',
+    'tieHalfSolid',
     'tieNeutral',
     'tieSolid',
     'tieUp',
@@ -422,9 +534,11 @@ lilypond_music_commands = (
     'tuplet', # since 2.18
     'tupletDown',
     'tupletNeutral',
+    'tupletSpan', #since 2.23
     'tupletUp',
     'tweak',
     'unaCorda',
+    'unfolded', # since 2.23
     'unfoldRepeats',
     'unHideNotes',
     'unit',
@@ -437,14 +551,20 @@ lilypond_music_commands = (
     'voiceNeutralStyle',
     'voiceOne',
     'voiceOneStyle',
+    'voices', # since 2.23
     'voiceThree',
     'voiceThreeStyle',
     'voiceTwo',
     'voiceTwoStyle',
+    'void', # since 2.23
+    'vshape', # since 2.23
     'walkerHeads',
     'walkerHeadsMinor',
     'whiteTriangleMarkup',
     'withMusicProperty',
+    'xNote',
+    'xNotesOff',
+    'xNotesOn',
 )
 
 
@@ -460,95 +580,100 @@ articulations = (
 
 
 ornaments = (
-    'prall',
-    'mordent',
-    'prallmordent',
-    'turn',
-    'upprall',
-    'downprall',
-    'upmordent',
     'downmordent',
+    'downprall',
     'lineprall',
-    'prallprall',
+    'mordent',
+    'prall',
     'pralldown',
+    'prallmordent',
+    'prallprall',
     'prallup',
     'reverseturn',
     'trill',
+    'turn',
+    'upmordent',
+    'upprall',
 )
 
 
 fermatas = (
-    'shortfermata',
     'fermata',
     'longfermata',
+    'shortfermata',
     'verylongfermata',
 )
 
 
 instrument_scripts = (
-    'upbow',
     'downbow',
     'flageolet',
-    'thumb',
-    'snappizzicato',
-    'open',
     'halfopen',
-    'stopped',
     'lheel',
-    'rheel',
     'ltoe',
+    'open',
+    'rheel',
     'rtoe',
+    'snappizzicato',
+    'stopped',
+    'thumb',
+    'upbow',
 )
 
 
 repeat_scripts = (
-    'segno',
     'coda',
+    'segno',
     'varcoda',
 )
 
 
 ancient_scripts = (
-    'ictus',
     'accentus',
     'circulus',
+    'ictus',
     'semicirculus',
     'signumcongruentiae',
 )
 
 
 modes = (
+    'aeolian',
+    'dorian',
+    'ionian',
+    'locrian',
+    'lydian',
     'major',
     'minor',
-    'ionian',
-    'dorian',
-    'phrygian',
-    'lydian',
     'mixolydian',
-    'aeolian',
-    'locrian',
+    'phrygian',
 )
 
 
 markupcommands_nargs = (
 # no arguments
 (
+    'coda',
     'doubleflat',
     'doublesharp',
     'eyeglasses',
+    'fermata',
     'flat',
     'natural',
     'null',
+    'segno',
     'semiflat',
     'semisharp',
     'sesquiflat',
     'sesquisharp',
     'sharp',
     'strut',
-    'table-of-contents'
+    'table-of-contents',
+    'varcoda',
 ),
 # one argument
 (
+    'accidental',
     'backslashed-digit',
     'bold',
     'box',
@@ -559,15 +684,22 @@ markupcommands_nargs = (
     'char',
     'circle',
     'column',
+    'compound-meter',
     'concat',
     'dir-column',
+    'discant',
     'draw-dashed-line', # since 2.18
     'draw-dotted-line', # since 2.18
+    'draw-hline',
     'draw-line',
     'dynamic',
+    'ellipse',
     'fill-line',
+    'figured-bass',
     'finger',
+    'first-visible',
     'fontCaps',
+    'freeBass',
     'fret-diagram',
     'fret-diagram-terse',
     'fret-diagram-verbose',
@@ -591,6 +723,7 @@ markupcommands_nargs = (
     'markalphabet',
     'markletter',
     'medium',
+    'multi-measure-rest-by-number',
     'musicglyph',
     'normalsize',
     'normal-size-sub',
@@ -600,20 +733,26 @@ markupcommands_nargs = (
     'oval', # since 2.18
     'overlay', # since 2.20
     'overtie', # since 2.20
+    'polygon',
     'postscript',
+    'property-recursive',
+    'rest',
     'right-align',
     'right-brace',
     'right-column',
     'roman',
     'rounded-box',
+    'rhythm',
     'sans',
     'score',
+    'score-lines',
     'simple',
     'slashed-digit',
     'small',
     'smallCaps',
     'smaller',
     'stencil',
+    'string-lines',
     'sub',
     'super',
     'teeny',
@@ -628,9 +767,10 @@ markupcommands_nargs = (
     'undertie', # since 2.20
     'upright',
     'vcenter',
-    'vspace',
     'verbatim-file',
+    'vspace',
     'whiteout',
+    'with-true-dimensions',
     'wordwrap',
     'wordwrap-field',
     'wordwrap-string',
@@ -646,6 +786,7 @@ markupcommands_nargs = (
     'fraction',
     'halign',
     'hcenter-in',
+    'if',
     'lower',
     'magnify',
     'note',
@@ -657,15 +798,21 @@ markupcommands_nargs = (
     'page-link',
     'path',     # added in LP 2.13.31
     'raise',
+    'replace',
+    'rest-by-number',
     'rotate',
     'scale',
     'translate',
     'translate-scaled',
+    'unless',
     'with-color',
+    'with-dimensions-from', # since 2.20
     'with-link',
+    'with-outline',
+    'with-string-transformer',
+    'with-true-dimension',
     'with-url',
     'woodwind-diagram',
-    'with-dimensions-from', # since 2.20
 ),
 # three arguments
 (
@@ -679,6 +826,8 @@ markupcommands_nargs = (
     'note-by-number',
     'pad-to-box',
     'page-ref',
+    'with-dimension',
+    'with-dimension-from',
     'with-dimensions',
 ),
 # four arguments
@@ -688,6 +837,7 @@ markupcommands_nargs = (
 ),
 # five arguments,
 (
+    'align-on-other',
     'fill-with-pattern',
 ),
 )
@@ -708,6 +858,8 @@ markuplistcommands = (
 
 contexts = (
     'ChoirStaff',
+    'ChordGrid',
+    'ChordGridScore',
     'ChordNames',
     'CueVoice',
     'Devnull',
@@ -718,8 +870,10 @@ contexts = (
     'FretBoards',
     'Global',
     'GrandStaff',
+    'GregorianTranscriptionLyrics',
     'GregorianTranscriptionStaff',
     'GregorianTranscriptionVoice',
+    'InternalGregorianStaff',
     'KievanStaff', # since 2.16
     'KievanVoice', # since 2.16
     'Lyrics',
@@ -727,6 +881,7 @@ contexts = (
     'MensuralVoice',
     'NoteNames',
     'NullVoice',     # since 2.18
+    'OneStaff',
     'PetrucciStaff', # since 2.16
     'PetrucciVoice', # since 2.16
     'PianoStaff',
@@ -734,9 +889,13 @@ contexts = (
     'Score',
     'Staff',
     'StaffGroup',
+    'StandaloneRhythmScore',
+    'StandaloneRhythmStaff',
+    'StandaloneRhythmVoice',
     'TabStaff',
     'TabVoice',
     'Timing',
+    'VaticanaLyrics',
     'VaticanaStaff',
     'VaticanaVoice',
     'Voice',
@@ -916,6 +1075,39 @@ midi_instruments = (
     'cm-64 drums',
 )
 
+# Follow the order of lilypond sources in ly/string-tunings-init.ly
+string_tunings = (
+    'guitar-tuning',
+    'guitar-seven-string-tuning',
+    'guitar-drop-d-tuning',
+    'guitar-drop-c-tuning',
+    'guitar-open-g-tuning',
+    'guitar-open-d-tuning',
+    'guitar-dadgad-tuning',
+    'guitar-lute-tuning',
+    'guitar-asus4-tuning',
+    'bass-tuning',
+    'bass-four-string-tuning',
+    'bass-drop-d-tuning',
+    'bass-five-string-tuning',
+    'bass-six-string-tuning',
+    'mandolin-tuning',
+    'banjo-open-g-tuning',
+    'banjo-c-tuning',
+    'banjo-modal-tuning',
+    'banjo-open-d-tuning',
+    'banjo-open-dm-tuning',
+    'banjo-double-c-tuning',
+    'banjo-double-d-tuning',
+    'ukulele-tuning',
+    'ukulele-d-tuning',
+    'tenor-ukulele-tuning',
+    'baritone-ukulele-tuning',
+    'violin-tuning',
+    'viola-tuning',
+    'cello-tuning',
+    'double-bass-tuning',
+)
 
 #scheme_functions = (
 #    'set-accidental-style',
@@ -963,36 +1155,36 @@ scheme_values = (
 
 
 headervariables = (
-    'dedication',
-    'title',
-    'subtitle',
-    'subsubtitle',
-    'poet',
-    'composer',
-    'meter',
-    'opus',
     'arranger',
-    'instrument',
-    'piece',
     'breakbefore',
+    'composer',
     'copyright',
-    'tagline',
-    'mutopiatitle',
-    'mutopiacomposer',
-    'mutopiapoet',
-    'mutopiaopus',
-    'mutopiainstrument',
     'date',
+    'dedication',
     'enteredby',
-    'source',
-    'style',
+    'footer',
+    'instrument',
+    'lastupdated',
     'maintainer',
     'maintainerEmail',
     'maintainerWeb',
+    'meter',
     'moreInfo',
-    'lastupdated',
+    'mutopiacomposer',
+    'mutopiainstrument',
+    'mutopiaopus',
+    'mutopiapoet',
+    'mutopiatitle',
+    'opus',
+    'piece',
+    'poet',
+    'source',
+    'style',
+    'subsubtitle',
+    'subtitle',
+    'tagline',
     'texidoc',
-    'footer',
+    'title',
 )
 
 
@@ -1051,6 +1243,7 @@ papervariables = (
     'print-page-number',
 
     # misc
+    'footnote-separator-markup',
     'page-spacing-weight',
     'print-all-headers',
     'system-separator-markup',
@@ -1081,11 +1274,11 @@ papervariables = (
 
 layoutvariables = (
     'indent',
+    'line-width',
+    'ragged-last',
+    'ragged-right',
     'short-indent',
     'system-count',
-    'line-width',
-    'ragged-right',
-    'ragged-last',
 )
 
 
@@ -1094,81 +1287,133 @@ midivariables = (
 
 
 repeat_types = (
-    'unfold',
     'percent',
-    'volta',
+    'segno',
     'tremolo',
+    'unfold',
+    'volta',
 )
 
 
 accidentalstyles = (
+    'choral', # since 2.20
+    'choral-cautionary', # since 2.20
     'default',
-    'voice',
+    'dodecaphonic',
+    'forget',
     'modern',
     'modern-cautionary',
     'modern-voice',
     'modern-voice-cautionary',
-    'piano',
-    'piano-cautionary',
-    'choral', # since 2.20
-    'choral-cautionary', # since 2.20
     'neo-modern',
     'neo-modern-cautionary',
     'neo-modern-voice',
     'neo-modern-voice-cautionary',
-    'dodecaphonic',
-    'teaching',
     'no-reset',
-    'forget',
+    'piano',
+    'piano-cautionary',
+    'teaching',
+    'voice',
 )
 
 
 clefs_plain = (
     'alto',
+    'altovarC',
     'baritone',
+    'baritonevarC',
+    'baritonevarF',
     'bass',
+    'blackmensural-c1',
+    'blackmensural-c2',
+    'blackmensural-c3',
+    'blackmensural-c4',
+    'blackmensural-c5',
     'C',
     'F',
     'french',
     'G',
     'GG',               # since 2.19
+    'G2',
+    'hufnagel-do-fa',
+    'hufnagel-do1',
+    'hufnagel-do2',
+    'hufnagel-do3',
+    'hufnagel-fa1',
+    'hufnagel-fa2',
+    'kievan-do',
+    'medicaea-do1',
+    'medicaea-do2',
+    'medicaea-do3',
+    'medicaea-fa1',
+    'medicaea-fa2',
+    'mensural-c1',
+    'mensural-c2',
+    'mensural-c3',
+    'mensural-c4',
+    'mensural-c5',
+    'mensural-f',
+    'mensural-g',
     'mezzosoprano',
+    'moderntab',
+    'neomensural-c1',
+    'neomensural-c2',
+    'neomensural-c3',
+    'neomensural-c4',
+    'neomensural-c5',
     'percussion',
+    'petrucci-c1',
+    'petrucci-c2',
+    'petrucci-c3',
+    'petrucci-c4',
+    'petrucci-c5',
+    'petrucci-f',
+    'petrucci-f2',
+    'petrucci-f3',
+    'petrucci-f4',
+    'petrucci-f5',
+    'petrucci-g',
+    'petrucci-g1',
+    'petrucci-g2',
     'soprano',
     'subbass',
     'tab',
     'tenor',
     'tenorG',           # since 2.19
+    'tenorvarC',
     'treble',
     'varbaritone',
     'varC',             # since 2.19
     'varpercussion',    # since 2.19
+    'vaticana-do1',
+    'vaticana-do2',
+    'vaticana-do3',
+    'vaticana-fa1',
+    'vaticana-fa2',
     'violin',
 )
 
 
 clefs = clefs_plain + (
-    'treble_8',
     'bass_8',
+    'treble_8',
 )
 
 
 break_visibility = (
     'all-invisible',
-    'begin-of-line-visible',
-    'end-of-line-visible',
     'all-visible',
     'begin-of-line-invisible',
-    'end-of-line-invisible',
+    'begin-of-line-visible',
     'center-invisible',
+    'end-of-line-invisible',
+    'end-of-line-visible',
 )
 
 
 mark_formatters = (
     'format-mark-alphabet',
     'format-mark-barnumbers',
-    'format-mark-letters',
-    'format-mark-numbers',
     'format-mark-box-alphabet',
     'format-mark-box-barnumbers',
     'format-mark-box-letters',
@@ -1177,6 +1422,8 @@ mark_formatters = (
     'format-mark-circle-barnumbers',
     'format-mark-circle-letters',
     'format-mark-circle-numbers',
+    'format-mark-letters',
+    'format-mark-numbers',
 )
 
 
